@@ -9,6 +9,7 @@
 #' @param rate The nominal interest rate per period (should be positive)
 #' @param nper Number of periods
 #' @param pmt Instalment per period (should be negative)
+#' @param fv      Future value i.e. redemption amount
 #' @return pv Present value i.e. loan advance (should be positive)
 #'
 #' @keywords financial pv pmt
@@ -23,7 +24,11 @@
 #' PV(df$rate,df$nper,df$pmt)  # c(68.14,134.77) Taken from excel
 
 
-PV<-function(rate, nper, pmt){
-  stopifnot(rate>0,rate<1,nper>=1,pmt<0)
- return(round(-pmt / rate * (1 - 1 / (1 + rate) ^ nper),2))
-}
\ No newline at end of file
+PV <- function(rate, nper, pmt, fv = 0) {
+    stopifnot(is.numeric(rate), is.numeric(nper), is.numeric(pmt), is.numeric(fv), rate > 0, rate < 1, nper >= 1, pmt < 0)
+    
+    pvofregcash <- -pmt/rate * (1 - 1/(1 + rate)^nper)
+    pvoffv <- fv/((1 + rate)^nper)
+    
+    return(round(pvofregcash - pvoffv, 2))
+} 
